@@ -2,23 +2,26 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-"""Module for providing specific timezones"""
+"""Module for providing specific timezones."""
+
+from __future__ import absolute_import, unicode_literals
 
 from datetime import datetime, timedelta, tzinfo
 
 
 class PacificTimezone(tzinfo):
-    """Class to set the timezone to PST/PDT and automatically adjusts
-    for daylight saving.
-    """
+    """Class to set the timezone to PST/PDT, and adjusts for daylight saving."""
 
     def utcoffset(self, dt):
+        """Offset from PST/PDT to UTC."""
         return timedelta(hours=-8) + self.dst(dt)
 
     def tzname(self, dt):
+        """Name of the timezone."""
         return "Pacific"
 
     def dst(self, dt):
+        """Calculate delta for daylight saving."""
         # Daylight saving starts on the second Sunday of March at 2AM standard
         dst_start_date = self.first_sunday(dt.year, 3) + timedelta(days=7) \
                                                        + timedelta(hours=2)
@@ -31,6 +34,7 @@ class PacificTimezone(tzinfo):
             return timedelta(0)
 
     def first_sunday(self, year, month):
+        """Get the first sunday of a month."""
         date = datetime(year, month, 1, 0)
         days_until_sunday = 6 - date.weekday()
 
